@@ -5,9 +5,10 @@ use warnings;
 use base 'Padre::Task';
 use Scalar::Util    ();
 use Padre::Constant ();
+use Padre::Debug;
 use Padre::Util     ();
 
-our $VERSION        = '0.60';
+our $VERSION        = '0.61';
 our $thread_running = 0;
 
 # This is run in the main thread before being handed
@@ -213,7 +214,7 @@ sub run {
 
 		# remove ANSI color escape sequences...
 		$err =~ s/\033\[\d+(?:;\d+(?:;\d+)?)?m//g;
-		Padre::Util::debug(qq{STD.pm warning/error:\n$err\n});
+		TRACE(qq{STD.pm warning/error:\n$err\n}) if DEBUG;
 		my @messages = split /\n/, $err;
 		my ( $lineno, $severity );
 		my $issues = [];
